==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN вкл</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN выкл</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock вкл</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock выкл</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Цифровая клавиатура вкл</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Цифровая клавиатура выкл</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Тачпад вкл</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Тачпад выкл</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Переключатель тачпада</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Переключатель Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Авиарежим вкл </translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Авиарежим выкл </translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Звук выкл</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Звук вкл</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Сбалансированный режим</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Экономия заряда</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Высокая производительность</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Оконные эффекты вкл</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Оконные эффекты выкл</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Не удалось включить эффекты окон</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN вкл</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN выкл</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock вкл</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock выкл</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Цифровая клавиатура вкл</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Цифровая клавиатура выкл</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Тачпад вкл</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Тачпад выкл</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Переключатель тачпада</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Переключатель Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Авиарежим вкл </translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Авиарежим выкл </translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Звук выкл</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Звук вкл</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Сбалансированный режим</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Экономия заряда</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Высокая производительность</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Оконные эффекты вкл</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Оконные эффекты выкл</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Не удалось включить эффекты окон</translation>
    </message>
</context>
</TS>
